@@ -130,6 +130,19 @@ static void chat_emit_alert_list(void){
 ** The value must be the name of a builtin WAV file.
 */
 /*
+** SETTING: chat-timeline-user    width=10
+**
+** If this setting is defined and is not an empty string, then
+** timeline events are posted to the chat as they arrive. The synthesized
+** chat messages appear to come from the user identified by this setting,
+** not the user on the timeline event.
+**
+** All chat messages that come from the chat-timeline-user are
+** interpreted as text/x-fossil-wiki instead of as text/x-markdown.
+** For this reason, the chat-timeline-user name should probably not be
+** a real user.
+*/
+/*
 ** WEBPAGE: chat loadavg-exempt
 **
 ** Start up a browser-based chat session.
@@ -382,6 +395,7 @@ void chat_send_webpage(void){
   nByte = atoi(PD("file:bytes","0"));
   zMsg = PD("msg","");
   db_begin_write();
+  db_unprotect(PROTECT_READONLY);
   chat_purge();
   if( nByte==0 ){
     if( zMsg[0] ){
@@ -405,22 +419,31 @@ void chat_send_webpage(void){
     db_finalize(&q);
     blob_reset(&b);
   }
+  db_protect_pop();
   db_commit_transaction();
 }
 
 /*
-** This routine receives raw (user-entered) message text and transforms
-** it into HTML that is safe to insert using innerHTML. As of 2021-09-19,
-** it does so by using markdown_to_html() to convert markdown-formatted
-** zMsg to HTML.
+** This routine receives raw (user-entered) message text and
+** transforms it into HTML that is safe to insert using innerHTML. As
+** of 2021-09-19, it does so by using wiki_convert() or
+** markdown_to_html() to convert wiki/markdown-formatted zMsg to HTML.
 **
 ** Space to hold the returned string is obtained from fossil_malloc()
 ** and must be freed by the caller.
 */
-static char *chat_format_to_html(const char *zMsg){
+static char *chat_format_to_html(const char *zMsg, int isWiki){
   Blob out;
   blob_init(&out, "", 0);
-  if(*zMsg){
+  if( zMsg==0 || zMsg[0]==0 ){
+    /* No-op */
+  }else if( isWiki ){
+    /* Used for chat-timeline-user.  The zMsg is text/x-fossil-wiki. */
+    Blob bIn;
+    blob_init(&bIn, zMsg, (int)strlen(zMsg));
+    wiki_convert(&bIn, &out, WIKI_INLINE);
+  }else{
+    /* The common case:  zMsg is text/x-markdown */
     Blob bIn;
     blob_init(&bIn, zMsg, (int)strlen(zMsg));
     markdown_to_html(&bIn, NULL, &out);
@@ -444,7 +467,7 @@ void chat_test_formatter_cmd(void){
   db_find_and_open_repository(0,0);
   g.perm.Hyperlink = 1;
   for(i=0; i<g.argc; i++){
-    zOut = chat_format_to_html(g.argv[i]);
+    zOut = chat_format_to_html(g.argv[i], 0);
     fossil_print("[%d]: %s\n", i, zOut);
     fossil_free(zOut);
   }
@@ -547,10 +570,13 @@ void chat_poll_webpage(void){
   sqlite3_int64 dataVersion;  /* Data version.  Used for polling. */
   const int iDelay = 1000;    /* Delay until next poll (milliseconds) */
   int nDelay;                 /* Maximum delay.*/
+  const char *zChatUser;      /* chat-timeline-user */
+  int isWiki = 0;             /* True if chat message is x-fossil-wiki */
   int msgid = atoi(PD("name","0"));
   const int msgBefore = atoi(PD("before","0"));
   int nLimit = msgBefore>0 ? atoi(PD("n","0")) : 0;
   const int bRaw = P("raw")!=0;
+
   Blob sql = empty_blob;
   Stmt q1;
   nDelay = db_get_int("chat-poll-timeout",420);  /* Default about 7 minutes */
@@ -559,6 +585,7 @@ void chat_poll_webpage(void){
     chat_emit_permissions_error(1);
     return;
   }
+  zChatUser = db_get("chat-timeline-user",0);
   chat_create_tables();
   cgi_set_content_type("application/json");
   dataVersion = db_int64(0, "PRAGMA data_version");
@@ -621,17 +648,19 @@ void chat_poll_webpage(void){
       blob_append(&json, "\"xfrom\":", -1);
       if(zFrom){
         blob_appendf(&json, "%!j,", zFrom);
+        isWiki = fossil_strcmp(zFrom,zChatUser)==0;
       }else{
         /* see https://fossil-scm.org/forum/forumpost/e0be0eeb4c */
         blob_appendf(&json, "null,");
+        isWiki = 0;
       }
       blob_appendf(&json, "\"uclr\":%!j,",
-                   user_color(zFrom ? zFrom : "nobody"));
+                 isWiki ? "transparent" : user_color(zFrom ? zFrom : "nobody"));
 
       if(bRaw){
         blob_appendf(&json, "\"xmsg\":%!j,", zRawMsg);
       }else{
-        zMsg = chat_format_to_html(zRawMsg ? zRawMsg : "");
+        zMsg = chat_format_to_html(zRawMsg ? zRawMsg : "", isWiki);
         blob_appendf(&json, "\"xmsg\":%!j,", zMsg);
         fossil_free(zMsg);
       }
@@ -688,12 +717,15 @@ void chat_fetch_one(void){
   Blob json = empty_blob;   /* The json to be constructed and returned */
   const int fRaw = PD("raw",0)!=0;
   const int msgid = atoi(PD("name","0"));
+  const char *zChatUser;
+  int isWiki;
   Stmt q;
   login_check_credentials();
   if( !g.perm.Chat ) {
     chat_emit_permissions_error(0);
     return;
   }
+  zChatUser = db_get("chat-timeline-user",0);
   chat_create_tables();
   cgi_set_content_type("application/json");
   db_prepare(&q, 
@@ -718,17 +750,19 @@ void chat_fetch_one(void){
     blob_append(&json, "\"xfrom\":", -1);
     if(zFrom){
       blob_appendf(&json, "%!j,", zFrom);
+      isWiki = fossil_strcmp(zFrom, zChatUser)==0;
     }else{
       /* see https://fossil-scm.org/forum/forumpost/e0be0eeb4c */
       blob_appendf(&json, "null,");
+      isWiki = 0;
     }
     blob_appendf(&json, "\"uclr\":%!j,",
-                 user_color(zFrom ? zFrom : "nobody"));
+                 isWiki ? "transparent" : user_color(zFrom ? zFrom : "nobody"));
     blob_append(&json,"\"xmsg\":", 7);
     if(fRaw){
       blob_appendf(&json, "%!j,", zRawMsg);
     }else{
-      char * zMsg = chat_format_to_html(zRawMsg ? zRawMsg : "");
+      char * zMsg = chat_format_to_html(zRawMsg ? zRawMsg : "", isWiki);
       blob_appendf(&json, "%!j,", zMsg);
       fossil_free(zMsg);
     }
@@ -752,13 +786,30 @@ void chat_fetch_one(void){
 ** Download the CHAT.FILE attachment associated with a single chat
 ** entry.  The "name" query parameter begins with an integer that
 ** identifies the particular chat message. The integer may be followed
-** by a / and a filename, which will indicate to the browser to use
-** the indicated name when saving the file.
+** by a / and a filename, which will (A) indicate to the browser to
+** use the indicated name when saving the file and (B) be used to
+** guess the mimetype in some particular cases involving the "render"
+** flag.
+**
+** If the "render" URL parameter is provided, the blob has a size
+** greater than zero, and blob meets one of the following conditions
+** then the fossil-rendered form of that content is returned, rather
+** than the original:
+**
+** - Mimetype is text/x-markdown or text/markdown: emit HTML.
+**
+** - Mimetype is text/x-fossil-wiki or P("name") ends with ".wiki":
+**   emit HTML.
+**
+** - Mimetype is text/x-pikchr or P("name") ends with ".pikchr": emit
+**   image/svg+xml if rendering succeeds or text/html if rendering
+**   fails.
 */
 void chat_download_webpage(void){
   int msgid;
   Blob r;
   const char *zMime;
+  const char *zName = PD("name","0");
   login_check_credentials();
   if( !g.perm.Chat ){
     style_header("Chat Not Authorized");
@@ -769,11 +820,44 @@ void chat_download_webpage(void){
     return;
   }
   chat_create_tables();
-  msgid = atoi(PD("name","0"));
+  msgid = atoi(zName);
   blob_zero(&r);
   zMime = db_text(0, "SELECT fmime FROM chat wHERE msgid=%d", msgid);
   if( zMime==0 ) return;
   db_blob(&r, "SELECT file FROM chat WHERE msgid=%d", msgid);
+  if( r.nUsed>0 && P("render")!=0 ){
+    /* Maybe return fossil-rendered form of the content. */
+    Blob r2 = BLOB_INITIALIZER;    /* output target for rendering */
+    const char * zMime2 = 0;       /* adjusted response mimetype */
+    if(fossil_strcmp(zMime, "text/x-markdown")==0
+       /* Firefox uploads md files with the mimetype text/markdown */
+       || fossil_strcmp(zMime, "text/markdown")==0){
+      markdown_to_html(&r, 0, &r2);
+      safe_html(&r2);
+      zMime2 = "text/html";
+    }else if(fossil_strcmp(zMime, "text/x-fossil-wiki")==0
+             || sqlite3_strglob("*.wiki", zName)==0){
+      /* .wiki files get uploaded as application/octet-stream */
+      wiki_convert(&r, &r2, 0);
+      zMime2 = "text/html";
+    }else if(fossil_strcmp(zMime, "text/x-pikchr")==0
+             || sqlite3_strglob("*.pikchr",zName)==0){
+      /* .pikchr files get uploaded as application/octet-stream */
+      const char *zPikchr = blob_str(&r);
+      int w = 0, h = 0;
+      char *zOut = pikchr(zPikchr, "pikchr", 0, &w, &h);
+      if(zOut){
+        blob_append(&r2, zOut, -1);
+      }
+      zMime2 = w>0 ? "image/svg+xml" : "text/html";
+      free(zOut);
+    }
+    if(r2.aData!=0){
+      blob_swap(&r, &r2);
+      blob_reset(&r2);
+      zMime = zMime2;
+    }
+  }
   cgi_set_content_type(zMime);
   cgi_set_content(&r);
 }
@@ -851,6 +935,84 @@ void chat_backup_webpage(void){
   cgi_set_content(&chatDb);
 }
 
+/*
+** SQL Function: chat_msg_from_event(TYPE,OBJID,USER,MSG)
+**
+** This function returns HTML text that describes an entry from the EVENT
+** table (that is, a timeline event) for display in chat.  Parameters:
+**
+**    TYPE         The event type.  'ci', 'w', 't', 'g', and so forth
+**    OBJID        EVENT.OBJID
+**    USER         coalesce(EVENT.EUSER,EVENT.USER)
+**    MSG          coalesce(EVENT.ECOMMENT, EVENT.COMMENT)
+**
+** This function is intended to be called by the temp.chat_trigger1 trigger
+** which is created by alert_create_trigger() routine.
+*/
+void chat_msg_from_event(
+  sqlite3_context *context,
+  int argc,
+  sqlite3_value **argv
+){
+  const char *zType = (const char*)sqlite3_value_text(argv[0]);
+  int rid = sqlite3_value_int(argv[1]);
+  const char *zUser = (const char*)sqlite3_value_text(argv[2]);
+  const char *zMsg = (const char*)sqlite3_value_text(argv[3]);
+  char *zRes = 0;
+  
+  if( zType==0 || zUser==0 || zMsg==0 ) return;
+  if( zType[0]=='c' ){
+    /* Check-ins */
+    char *zBranch;
+    char *zUuid;
+
+    zBranch = db_text(0,
+       "SELECT value FROM tagxref"
+       " WHERE tagxref.rid=%d"
+       "   AND tagxref.tagid=%d"
+       "   AND tagxref.tagtype>0",
+       rid, TAG_BRANCH);
+    zUuid = db_text(0, "SELECT uuid FROM blob WHERE rid=%d", rid);
+    zRes = mprintf("%W (check-in: <a href='%R/info/%S'>%S</a>, "
+                   "user: <a href='%R/timeline?u=%t&c=%S'>%h</a>, "
+                   "branch: <a href='%R/timeline?r=%t&c=%S'>%h</a>)",
+             zMsg,
+             zUuid, zUuid,
+             zUser, zUuid, zUser,
+             zBranch, zUuid, zBranch
+    );
+    fossil_free(zBranch);
+    fossil_free(zUuid);
+  }else if( zType[0]=='w' ){
+    /* Wiki page changes */
+    char *zUuid;
+    zUuid = db_text(0, "SELECT uuid FROM blob WHERE rid=%d", rid);
+    wiki_hyperlink_override(zUuid);
+    if( zMsg[0]=='-' ){
+      zRes = mprintf("Delete wiki page <a href='%R/whistory?name=%t'>%h</a>",
+         zMsg+1, zMsg+1);
+    }else if( zMsg[0]=='+' ){
+      zRes = mprintf("Added wiki page <a href='%R/whistory?name=%t'>%h</a>",
+         zMsg+1, zMsg+1);
+    }else if( zMsg[0]==':' ){
+      zRes = mprintf("<a href='%R/wdiff?id=%!S'>Changes</a> to wiki page "
+                     "<a href='%R/whistory?name=%t'>%h</a>",
+         zUuid, zMsg+1, zMsg+1);
+    }else{
+      zRes = mprintf("%W", zMsg);
+    }
+    wiki_hyperlink_override(0);
+    fossil_free(zUuid);
+  }else{
+    /* Anything else */
+    zRes = mprintf("%W", zMsg);
+  }
+  if( zRes ){
+    sqlite3_result_text(context, zRes, -1, fossil_free);
+  }
+}
+
+
 /*
 ** COMMAND: chat
 **
@@ -880,7 +1042,7 @@ void chat_backup_webpage(void){
 **
 **        --all                  Download all chat content. Normally only
 **                               previously undownloaded content is retrieved.
-**        --debug                Additional debugging output.
+**        --debug                Additional debugging output
 **        --out DATABASE         Store CHAT table in separate database file
 **                               DATABASE rather that adding to local clone
 **        --unsafe               Allow the use of unencrypted http://
